==> cdk-alps-spec-rest-api-0.0.11.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.11](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.10...v0.0.11) (2020-11-25)


### Bug Fixes

* disable anti tamper check ([07965a6](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/07965a66bfa307ee46a1065c7ee49869d76c6d2a))

### 0.0.10 (2020-11-25)


### Bug Fixes

* disable anti tamper check ([ab2e485](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/ab2e48555cad623506c6dd1919c5e6e8efb1c9bb))

## [0.1.0](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.8...v0.1.0) (2020-11-25)


### Features

* cleanup ([772b8cc](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/772b8ccd7a97d9d46430e0f5071595c22760efe0))
* cleanup ([ad5125e](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/ad5125e54deebc2766e3271dbd37f05e35b64bb8))
* cleanup ([943944a](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/943944ae11eee82c34e127606b62a61f465b7745))
* operationIdToLambdaName mapping + unit test reconstruct ([317dcb3](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/317dcb3ba8f8102160f99e6d5f7a53a3d19e3b8e))
* operationIdToLambdaName mapping + unit test reconstruct ([1f8065e](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/1f8065ef212d9d770c0b53e9989fcbea6945557d))
* Readme thanks and explanations ([4143e9c](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/4143e9c7f617c1348722fbba80e59238b2b04f26))
* use alps unified repo for converting to open spec ([ed38a1b](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/ed38a1b6b3ed9a8e07a474096c7507bd23517132))
* use alps unified repo for converting to open spec ([e36a7f7](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/e36a7f75cf40e07c4e7b5d9bb2d9fa6d5df6cb0d))
* use alps unified repo for converting to open spec ([40cf9e3](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/40cf9e3a1c27bdb4a9bf2f7d843e1e436e831d2f)


### Bug Fixes

* disable anti tamper check ([c92497c](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/c92497ce59ddb1c48b8fd42d8ee6275e48b8eb98))
### [0.0.8](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.7...v0.0.8) (2020-11-25)


### Features

* add definitions ([37ac17a](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/37ac17a57ac4ed4d70a63f6ee2a64d7d2b6a8d16))
* parse spec file in JSON or YAML ([2f982cb](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/2f982cb7e5755906e671cc37fc44a9675a01d5cb))

### [0.0.7](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.6...v0.0.7) (2020-11-23)


### Features

* ALPS in Readme ([473ae94](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/473ae9456670ca6b3521d2eefc359bbd32456ad8))

### 0.0.6 (2020-11-23)

### [0.0.5](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.4...v0.0.5) (2020-11-23)

=======

### Features

- add unit tests ([1ed3a67](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/1ed3a67ff4d26b38d0373548976ba84f34889da8))

### [0.0.4](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.3...v0.0.4) (2020-11-23)

### Features

- add unit tests ([13b82bd](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/13b82bd553d09d5e96bddf5f282a23154c7ab89e))

### 0.0.3 (2020-11-23)

### Bug Fixes

- npm reg ([fbe4876](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/fbe4876845547cca958d614358505008a528d531))

### 0.0.2 (2020-11-23)

### 0.0.1 (2020-11-23)

==> cdk-alps-spec-rest-api-0.1.1.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.1](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.11...v0.1.1) (2020-11-25)


### Bug Fixes

* add limitation ([e960646](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/e96064638fff2623d9843a93170246b64bcdfbf5))
* add limitation ([f605fa7](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/f605fa744ffd324d7c94fc1cad69e13a2a7a5f11))

## [0.1.0](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.11...v0.1.0) (2020-11-25)


### Bug Fixes

* add limitation ([f605fa7](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/f605fa744ffd324d7c94fc1cad69e13a2a7a5f11))

### [0.0.11](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.10...v0.0.11) (2020-11-25)


### Bug Fixes

* disable anti tamper check ([07965a6](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/07965a66bfa307ee46a1065c7ee49869d76c6d2a))

### 0.0.10 (2020-11-25)


### Bug Fixes

* disable anti tamper check ([ab2e485](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/ab2e48555cad623506c6dd1919c5e6e8efb1c9bb))

## [0.1.0](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.8...v0.1.0) (2020-11-25)


### Features

* cleanup ([772b8cc](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/772b8ccd7a97d9d46430e0f5071595c22760efe0))
* cleanup ([ad5125e](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/ad5125e54deebc2766e3271dbd37f05e35b64bb8))
* cleanup ([943944a](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/943944ae11eee82c34e127606b62a61f465b7745))
* operationIdToLambdaName mapping + unit test reconstruct ([317dcb3](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/317dcb3ba8f8102160f99e6d5f7a53a3d19e3b8e))
* operationIdToLambdaName mapping + unit test reconstruct ([1f8065e](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/1f8065ef212d9d770c0b53e9989fcbea6945557d))
* Readme thanks and explanations ([4143e9c](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/4143e9c7f617c1348722fbba80e59238b2b04f26))
* use alps unified repo for converting to open spec ([ed38a1b](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/ed38a1b6b3ed9a8e07a474096c7507bd23517132))
* use alps unified repo for converting to open spec ([e36a7f7](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/e36a7f75cf40e07c4e7b5d9bb2d9fa6d5df6cb0d))
* use alps unified repo for converting to open spec ([40cf9e3](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/40cf9e3a1c27bdb4a9bf2f7d843e1e436e831d2f)


### Bug Fixes

* disable anti tamper check ([c92497c](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/c92497ce59ddb1c48b8fd42d8ee6275e48b8eb98))
### [0.0.8](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.7...v0.0.8) (2020-11-25)


### Features

* add definitions ([37ac17a](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/37ac17a57ac4ed4d70a63f6ee2a64d7d2b6a8d16))
* parse spec file in JSON or YAML ([2f982cb](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/2f982cb7e5755906e671cc37fc44a9675a01d5cb))

### [0.0.7](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.6...v0.0.7) (2020-11-23)


### Features

* ALPS in Readme ([473ae94](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/473ae9456670ca6b3521d2eefc359bbd32456ad8))

### 0.0.6 (2020-11-23)

### [0.0.5](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.4...v0.0.5) (2020-11-23)

=======

### Features

- add unit tests ([1ed3a67](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/1ed3a67ff4d26b38d0373548976ba84f34889da8))

### [0.0.4](https://github.com/mmuller88/cdk-alps-spec-rest-api/compare/v0.0.3...v0.0.4) (2020-11-23)

### Features

- add unit tests ([13b82bd](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/13b82bd553d09d5e96bddf5f282a23154c7ab89e))

### 0.0.3 (2020-11-23)

### Bug Fixes

- npm reg ([fbe4876](https://github.com/mmuller88/cdk-alps-spec-rest-api/commit/fbe4876845547cca958d614358505008a528d531))

### 0.0.2 (2020-11-23)

### 0.0.1 (2020-11-23)
